maildir_deduplicate.tests package
=================================

Submodules
----------

maildir_deduplicate.tests.case module
-------------------------------------

.. automodule:: maildir_deduplicate.tests.case
    :members:
    :undoc-members:
    :show-inheritance:

maildir_deduplicate.tests.test_cli module
-----------------------------------------

.. automodule:: maildir_deduplicate.tests.test_cli
    :members:
    :undoc-members:
    :show-inheritance:

maildir_deduplicate.tests.test_deduplicate module
-------------------------------------------------

.. automodule:: maildir_deduplicate.tests.test_deduplicate
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: maildir_deduplicate.tests
    :members:
    :undoc-members:
    :show-inheritance:
